CameraConfigFfi class final

Inheritance
Implemented types
Available extensions

Constructors

CameraConfigFfi()

Properties

active int
getter/setter pair
address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
autoFocus int
getter/setter pair
enableFrameProcessing int
getter/setter pair
exposure double
getter/setter pair
flash int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lowLightBoost int
getter/setter pair
pixelFormat int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samplingRate int
getter/setter pair
torch int
getter/setter pair
torchLevel double
getter/setter pair
videoHdr int
getter/setter pair
videoStabilization int
getter/setter pair
whiteBalanceKelvin int
getter/setter pair
zoom double
getter/setter pair

Methods

freeFields() → void

Available on CameraConfigFfi, provided by the CameraConfigFfiExt extension

Frees internal fields (like strings) that were allocated on the C heap. Does NOT free the struct itself.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDart() CameraConfig

Available on CameraConfigFfi, provided by the CameraConfigFfiExt extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited