updateOverlay abstract method

void updateOverlay(
  1. int textureId,
  2. @zeroCopy Uint8List overlayData
)

Draws a persistent shape or text vector onto the camera overlay. Renders directly on the GPU using the custom pipeline. overlayData is a serialized binary Buffer of draw commands.

Implementation

void updateOverlay(int textureId, @zeroCopy Uint8List overlayData);