PhotoOptionsProxy constructor

PhotoOptionsProxy(
  1. Pointer<PhotoOptionsFfi> _native
)

Takes ownership of native. Super fields are zeroed and never read; all getters below are overridden to read from native memory instead. Do NOT call malloc.free on the struct shell after passing it here, and do not free zero-copy field buffers while the proxy may be read.

Implementation

PhotoOptionsProxy(this._native)
  : super(
      flash: 0,
      qualityPrioritization: 0,
      enableShutterSound: 0,
      skipMetadata: 0,
      enableAutoRedEyeReduction: 0,
      latitude: 0.0,
      longitude: 0.0,
      altitude: 0.0,
      hasLocation: 0,
      outputFormat: 0,
    ) {
  assert(
    _finalizer != null,
    'PhotoOptionsProxy._init() was not called. Ensure the Nitro impl class constructor ran before creating proxies.',
  );
  _finalizer!.attach(this, _native.cast(), detach: this, externalSize: 512);
}