RecordingOptionsFfi class final

Inheritance
Implemented types
Available extensions

Constructors

RecordingOptionsFfi()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
altitude double
getter/setter pair
bitRate int
getter/setter pair
codec int
getter/setter pair
fileType int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasLocation int
getter/setter pair
latitude double
getter/setter pair
longitude double
getter/setter pair
maxDurationMs int
getter/setter pair
maxFileSizeBytes int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

freeFields() → void

Available on RecordingOptionsFfi, provided by the RecordingOptionsFfiExt extension

Frees internal fields (like strings) that were allocated on the C heap. Does NOT free the struct itself.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDart() RecordingOptions

Available on RecordingOptionsFfi, provided by the RecordingOptionsFfiExt extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited