RecordingOptionsProxy constructor

RecordingOptionsProxy(
  1. Pointer<RecordingOptionsFfi> _native
)

Takes ownership of native. Super fields are zeroed and never read; all getters below are overridden to read from native memory instead. Do NOT call malloc.free on the struct shell after passing it here, and do not free zero-copy field buffers while the proxy may be read.

Implementation

RecordingOptionsProxy(this._native)
  : super(
      codec: 0,
      fileType: 0,
      bitRate: 0,
      maxDurationMs: 0,
      maxFileSizeBytes: 0,
      latitude: 0.0,
      longitude: 0.0,
      altitude: 0.0,
      hasLocation: 0,
    ) {
  assert(
    _finalizer != null,
    'RecordingOptionsProxy._init() was not called. Ensure the Nitro impl class constructor ran before creating proxies.',
  );
  _finalizer!.attach(this, _native.cast(), detach: this, externalSize: 512);
}