ResolvedConfigFfi class final

Inheritance
Implemented types
Available extensions

Constructors

ResolvedConfigFfi()

Properties

active int
getter/setter pair
address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
autoFocusSystem int
getter/setter pair
fps int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
pixelFormat int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoHdrEnabled int
getter/setter pair
width int
getter/setter pair

Methods

freeFields() → void

Available on ResolvedConfigFfi, provided by the ResolvedConfigFfiExt extension

Frees internal fields (like strings) that were allocated on the C heap. Does NOT free the struct itself.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDart() ResolvedConfig

Available on ResolvedConfigFfi, provided by the ResolvedConfigFfiExt extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited