ResolvedConfigProxy constructor

ResolvedConfigProxy(
  1. Pointer<ResolvedConfigFfi> _native
)

Takes ownership of native. Super fields are zeroed and never read; all getters below are overridden to read from native memory instead. Do NOT call malloc.free on the struct shell after passing it here, and do not free zero-copy field buffers while the proxy may be read.

Implementation

ResolvedConfigProxy(this._native)
  : super(
      width: 0,
      height: 0,
      fps: 0,
      pixelFormat: 0,
      videoHdrEnabled: 0,
      autoFocusSystem: 0,
      active: 0,
    ) {
  assert(
    _finalizer != null,
    'ResolvedConfigProxy._init() was not called. Ensure the Nitro impl class constructor ran before creating proxies.',
  );
  _finalizer!.attach(this, _native.cast(), detach: this, externalSize: 512);
}