CameraEventType enum

Kind of CameraEvent delivered on NitroCamera.eventStream.

Inheritance
Available extensions
Annotations
  • @HybridEnum.new()

Values

started → const CameraEventType
stopped → const CameraEventType
error → const CameraEventType
interruptionStarted → const CameraEventType
interruptionEnded → const CameraEventType
frameDropped → const CameraEventType
photoCaptureBegan → const CameraEventType
photoCaptureShutter → const CameraEventType
photoThumbnail → const CameraEventType
deviceConnected → const CameraEventType
deviceDisconnected → const CameraEventType
orientationChanged → const CameraEventType
detection → const CameraEventType
thermalStateChanged → const CameraEventType

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
nativeValue → int

Available on CameraEventType, provided by the CameraEventTypeNativeExt extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<CameraEventType>
A constant List of the values in this enum, in order of their declaration.