InterruptionReason enum

Why the camera session was interrupted (mirrors AVFoundation reasons).

Inheritance
Available extensions
Annotations
  • @HybridEnum.new()

Values

none → const InterruptionReason
videoDeviceNotAvailableInBackground → const InterruptionReason
audioDeviceInUseByAnotherClient → const InterruptionReason
videoDeviceInUseByAnotherClient → const InterruptionReason
videoDeviceNotAvailableWithMultipleForegroundApps → const InterruptionReason
videoDeviceNotAvailableDueToSystemPressure → const InterruptionReason
unknown → const InterruptionReason

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
nativeValue int

Available on InterruptionReason, provided by the InterruptionReasonNativeExt extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<InterruptionReason>
A constant List of the values in this enum, in order of their declaration.