CameraDevice class
Describes a physical camera device available on the hardware.
- Available extensions
- Annotations
-
- @hybridRecord
Constructors
- CameraDevice({required String id, required String name, required int position, int lensType = 0, required int sensorOrientation, double minZoom = 1.0, required double maxZoom, required double neutralZoom, int hasFlash = 0, int hasTorch = 0, required int maxPhotoWidth, required int maxPhotoHeight, double focalLength = 3.5, double aperture = 1.8})
-
const
Properties
- aperture → double
-
final
- focalLength → double
-
final
- hasFlash → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasTorch → int
-
final
- id → String
-
final
- lensType → int
-
final
- maxPhotoHeight → int
-
final
- maxPhotoWidth → int
-
final
- maxZoom → double
-
final
- minZoom → double
-
final
- name → String
-
final
- neutralZoom → double
-
final
- position → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sensorOrientation → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
Allocator alloc) → Pointer< Uint8> -
Available on CameraDevice, provided by the CameraDeviceRecordExt extension
-
toString(
) → String -
A string representation of this object.
inherited
-
writeFields(
RecordWriter writer) → void -
Available on CameraDevice, provided by the CameraDeviceRecordExt extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited