CameraFrameFfi class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - bytesPerRow ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int
-
getter/setter pair
- isMirrored ↔ int
-
getter/setter pair
- orientation ↔ int
-
getter/setter pair
- pixelFormat ↔ int
-
getter/setter pair
-
pixels
↔ Pointer<
Uint8> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size ↔ int
-
getter/setter pair
- textureId ↔ int
-
getter/setter pair
- timestamp ↔ int
-
getter/setter pair
- width ↔ int
-
getter/setter pair
Methods
-
freeFields(
) → void -
Available on CameraFrameFfi, provided by the CameraFrameFfiExt extension
Frees internal fields (like strings) that were allocated on the C heap. Does NOT free the struct itself. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDart(
) → CameraFrame -
Available on CameraFrameFfi, provided by the CameraFrameFfiExt extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited