PhotoOptions class

Per-capture options for NitroCamera.takePhotoWithOptions.

Implementers
Available extensions
Annotations
  • @HybridStruct.new()

Constructors

PhotoOptions({required int flash, required int qualityPrioritization, required int enableShutterSound, required int skipMetadata, required int enableAutoRedEyeReduction, double latitude = 0, double longitude = 0, double altitude = 0, int hasLocation = 0, int outputFormat = 0})
const

Properties

altitude double
final
enableAutoRedEyeReduction int
final
enableShutterSound int
final
flash int
final
hashCode int
The hash code for this object.
no setterinherited
hasLocation int
final
latitude double
final
longitude double
final
outputFormat int
final
qualityPrioritization int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipMetadata int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative(Arena arena) Pointer<PhotoOptionsFfi>

Available on PhotoOptions, provided by the PhotoOptionsExt extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited