PhotoOptionsFfi class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - altitude ↔ double
-
getter/setter pair
- enableAutoRedEyeReduction ↔ int
-
getter/setter pair
- enableShutterSound ↔ int
-
getter/setter pair
- flash ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasLocation ↔ int
-
getter/setter pair
- latitude ↔ double
-
getter/setter pair
- longitude ↔ double
-
getter/setter pair
- outputFormat ↔ int
-
getter/setter pair
- qualityPrioritization ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipMetadata ↔ int
-
getter/setter pair
Methods
-
freeFields(
) → void -
Available on PhotoOptionsFfi, provided by the PhotoOptionsFfiExt extension
Frees internal fields (like strings) that were allocated on the C heap. Does NOT free the struct itself. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDart(
) → PhotoOptions -
Available on PhotoOptionsFfi, provided by the PhotoOptionsFfiExt extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited